package com.jiuqi.syntax;

import java.io.PrintStream;
import java.util.HashMap;

/* loaded from: com_jiuqi_syntax.jar:com/jiuqi/syntax/NiporlanItemFactory.class */
public class NiporlanItemFactory {
    private static NiporlanItemFactory globalFactory = new NiporlanItemFactory();
    private static boolean useGlobalFactory = true;
    protected static HashMap OP_NIS = new HashMap();
    protected static NiporlanItem BOOL_TRUE_NI;
    protected static NiporlanItem BOOL_FALSE_NI;
    protected static NiporlanItem BOOL_NULL_NI;
    protected static int PAGE_COUNT;
    public PrintStream logger = null;
    private long id = System.currentTimeMillis();
    protected HashMap FUNC_NIS = new HashMap();
    public int FOUND_COUNT = 0;
    public int MISSED_COUNT = 0;
    public int NULL_COUNT = 0;
    protected HashMap[] dataCellCache = null;

    static {
        for (int i = 1; i <= 20; i++) {
            OP_NIS.put(new Integer(i), new NiporlanItem(i));
        }
        CommonData cd = new CommonData();
        cd.type = 5;
        cd.isNull = false;
        cd.cdBool = true;
        BOOL_TRUE_NI = new NiporlanItem(cd);
        CommonData cd2 = new CommonData();
        cd2.type = 5;
        cd2.isNull = false;
        cd2.cdBool = false;
        BOOL_FALSE_NI = new NiporlanItem(cd2);
        CommonData cd3 = new CommonData();
        cd3.type = 5;
        cd3.isNull = true;
        BOOL_NULL_NI = new NiporlanItem(cd3);
        PAGE_COUNT = 2000;
    }

    public static boolean getUseGlobalFactory() {
        return useGlobalFactory;
    }

    public static void setUseGlobalFactory(boolean value) {
        useGlobalFactory = value;
    }

    public static NiporlanItemFactory getFactory() {
        if (useGlobalFactory) {
            return globalFactory;
        }
        return new NiporlanItemFactory();
    }

    public NiporlanItemFactory() {
        if (this.logger != null) {
            this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\tCrate NO." + this.id + " NIFactory.");
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v1, types: [java.util.HashMap] */
    /* JADX WARN: Type inference failed for: r0v2, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v7 */
    public NiporlanItem getNiporlanItem(int opCode) {
        ?? r0 = OP_NIS;
        synchronized (r0) {
            NiporlanItem ni = (NiporlanItem) OP_NIS.get(new Integer(opCode));
            if (ni == null) {
                ni = new NiporlanItem(opCode);
                OP_NIS.put(new Integer(opCode), ni);
                if (this.logger != null) {
                    this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\t添加新的操作符(" + opCode + ")共享NiporlanItem ");
                }
            }
            r0 = r0;
            return ni;
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v10 */
    /* JADX WARN: Type inference failed for: r0v3, types: [java.util.HashMap] */
    /* JADX WARN: Type inference failed for: r0v4, types: [java.lang.Throwable] */
    public NiporlanItem getNiporlanItem(String funcName) {
        if (funcName == null) {
            return null;
        }
        ?? r0 = this.FUNC_NIS;
        synchronized (r0) {
            NiporlanItem ni = (NiporlanItem) this.FUNC_NIS.get(funcName);
            if (ni == null) {
                ni = new NiporlanItem(funcName);
                this.FUNC_NIS.put(funcName, ni);
                if (this.logger != null) {
                    this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\t添加新的函数(" + funcName + ")共享NiporlanItem ");
                }
            }
            r0 = r0;
            return ni;
        }
    }

    public NiporlanItem getNiporlanItem(CommonData commonData) {
        if (commonData != null && commonData.type == 5) {
            if (commonData.isNull) {
                return BOOL_NULL_NI;
            }
            if (commonData.cdBool) {
                return BOOL_TRUE_NI;
            }
            if (!commonData.cdBool) {
                return BOOL_FALSE_NI;
            }
        }
        return new NiporlanItem(commonData);
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v24 */
    /* JADX WARN: Type inference failed for: r0v25, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r0v32 */
    public NiporlanItem getNiporlanItem(DataCell dataCell) {
        if (this.dataCellCache == null) {
            this.dataCellCache = new HashMap[PAGE_COUNT];
            for (int i = 0; i < this.dataCellCache.length; i++) {
                this.dataCellCache[i] = new HashMap();
            }
            if (this.logger != null) {
                this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\tDataCell缓冲池初始化 " + System.currentTimeMillis());
            }
        }
        if (dataCell == null) {
            if (this.logger != null) {
                this.logger.println(" DataCell is null");
            }
            return new NiporlanItem(dataCell);
        }
        int index = dataCell.tableOffset;
        if (index < 0) {
            index = -index;
        }
        HashMap page = this.dataCellCache[index % PAGE_COUNT];
        String mapKey = dataCell.toString();
        DataCell oldDataCell = (DataCell) page.get(mapKey);
        if (oldDataCell == null) {
            ?? r0 = page;
            synchronized (r0) {
                if (this.logger != null) {
                    this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\t未命中 " + mapKey);
                }
                oldDataCell = (DataCell) page.get(mapKey);
                if (oldDataCell == null) {
                    if (this.logger != null) {
                        this.logger.println(String.valueOf(Thread.currentThread().getName()) + "\t连续未命中 " + mapKey);
                    }
                    DataCell newDataCell = new DataCell();
                    newDataCell.assign(dataCell);
                    page.put(mapKey, newDataCell);
                }
                r0 = r0;
            }
        }
        if (oldDataCell != null && oldDataCell.statItem == dataCell.statItem && oldDataCell.offset == dataCell.offset) {
            return new NiporlanItem(oldDataCell);
        }
        return new NiporlanItem(dataCell);
    }

    public NiporlanItem getNiporlanItem(Object obj) {
        return new NiporlanItem(obj);
    }

    public String getProductCountDesc() {
        return "Factory NO." + this.id;
    }

    public void destroy() {
        if (!useGlobalFactory && this != globalFactory) {
            this.FUNC_NIS.clear();
        }
    }
}
